pub struct ArrowIpcChunkWriter { /* private fields */ }Expand description
Writer used by backend encoders to push Arrow IPC bytes into an HTTP response stream without accumulating one full response buffer.
Implementations
Sourceimpl ArrowIpcChunkWriter
impl ArrowIpcChunkWriter
pub fn send_error(&self, err: AppError)